"""Tool for managing archives of syslog logfiles.

Copyright (c) 2009, Florian Wagner <florian@wagner-flo.net>.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""

import os.path as path
import syslog
import argparse

import slarch.actions

def slarch_main(args):
    def append(namespace):
        return slarch.actions.append(
            namespace.filename,
            namespace.archivepattern,
            namespace.logpattern,
            namespace.find_delim)

    def compress(namespace):
        return slarch.actions.compress(
            namespace.archivepattern,
            namespace.purge,
            namespace.compress)
    
    parser = argparse.ArgumentParser(prog=args[0])
    subparsers = parser.add_subparsers()
        
    # append
    parser_append = subparsers.add_parser(
        'append', help='append a given logfile to the archive')
    parser_append.set_defaults(func=append)
    parser_append.add_argument(
        'filename', help='filename of the log to append')
    parser_append.add_argument(
        'archivepattern',
        help='pattern for names of archive files')
    parser_append.add_argument(
        'logpattern',
        help='pattern for matching dates within logfile entries')
    parser_append.add_argument(
        '-f', '--find-delim',
        help=('search for DELIM in log lines and assume logpattern '
              'starts after it'),
        metavar='DELIM',
        default=None)
    
    # compress
    parser_compress = subparsers.add_parser(
        'compress', help='compress and/or purge old archive files')
    parser_compress.set_defaults(func=compress)
    parser_compress.add_argument(
        '-p', '--purge',
        metavar='MONTHS',
        help='delete all files older than MONTHS (default 24)',
        default=24,
        type=int)
    parser_compress.add_argument(
        '-c', '--compress',
        metavar='MONTHS',
        help='compress all files older than MONTHS (default 1)',
        default=1,
        type=int)
    parser_compress.add_argument(
        'archivepattern',
        help='pattern of filenames to work on')

    # parse arguments, init syslog and dispatch
    namespace = parser.parse_args(args[1:])
    syslog.openlog(path.basename(args[0]))
    return namespace.func(namespace)
